#[non_exhaustive]pub enum Error {
IncorrectMatrixLabels {
expected: usize,
actual: usize,
},
NotEnoughColumns {
line: usize,
needed: usize,
content: String,
},
TooManyColumns {
line: usize,
content: String,
},
ParseError {
line: usize,
content: String,
},
WrongNumberOfData {
n_data: usize,
},
IoError(Error),
}Expand description
Custom error type for DataMatrix operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IncorrectMatrixLabels
Row or column labels count does not match number of rows / columns
NotEnoughColumns
Line does not have enough columns.
TooManyColumns
More than one column found when expecting single column input.
ParseError
Parsing error at a line.
WrongNumberOfData
Incorrect number of data values; expected a square matrix packed row-wise.
IoError(Error)
Generic I/O error.